/*  $Id: OSXMLCmdRunner.java 1327 2012-05-24 06:24:03Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.xml;

import java.io.IOException;
import net.eduvax.util.OSCmdRunner;
import org.xml.sax.ContentHandler;
import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Helper for executing OS commands with XML outputs.
 * Sends xml stream to a Sax Parser, so XML data can be processed
 * on the fly.
 * @version $Id: OSXMLCmdRunner.java 1327 2012-05-24 06:24:03Z sdevaux $
 * @author Sebastien Devaux	
 */ 
public class OSXMLCmdRunner extends OSCmdRunner {
	/**	
	 * create new OS XML command runner
	 * @param command command line (program name + args)
	 * @param dh Sax Content and Error Handler
	 */ 
	public OSXMLCmdRunner(String[] command, DefaultHandler dh) {
		super(command);
		_contentHandler=dh;
		_errorHandler=dh;
	}
	/**	
	 * create new OS XML command runner
	 * @param command command line (program name + args)
	 * @param ch Sax Content Handler
	 * @param eh Sax Error Handler
	 */ 
	public OSXMLCmdRunner(String[] command, ContentHandler ch,
										ErrorHandler eh) {
		super(command);
		_contentHandler=ch;
		_errorHandler=eh;
	}
	/**
	 * Gets command standard output and send it to the Sax Parser.
	 */ 
	protected void processStarted() {
		try {
			SaxParser parser=SaxParser.getInputStreamParser(
						getProcess().getInputStream(),
						_contentHandler,
						_errorHandler);
			parser.parse();		
		}
		catch (SAXException saxex) {
            net.eduvax.util.ErrorHandler handler=getErrorHandler();
            Error err=new Error(ERR_XMLPARSE,Error.ELevel.ERR,saxex);
            err.addArg(getCommandLine()[0]);
		}
		catch (IOException ioex) {
            net.eduvax.util.ErrorHandler handler=getErrorHandler();
            Error err=new Error(ERR_ISTREAM,Error.ELevel.ERR,ioex);
            err.addArg(getCommandLine()[0]);
		}
	}
	/** sax content handler */
	private ContentHandler _contentHandler;
	/** sax error handler */
	private ErrorHandler _errorHandler;
    // error ids
    private final static String ERR_XMLPARSE="OSXMLCmdRunner.XMLPARSE";
    private final static String ERR_ISTREAM="OSXMLCmdRunner.ISTREAM";   
}

// vim:tabstop=4:
