/*  $Id: SwitchableSaxHandler.java 1343 2012-08-25 20:59:16Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.xml;

import java.io.IOException;
import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.DTDHandler;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import org.xml.sax.helpers.DefaultHandler;


public class SwitchableSaxHandler extends DefaultHandler {

    private final static DefaultHandler _dummyHandler=new DefaultHandler();
    private ContentHandler _contentHandler;
    private DTDHandler _dtdHandler;
    private EntityResolver _entityResolver;
    private ErrorHandler _errorHandler;

    public SwitchableSaxHandler() {
        _contentHandler=_dummyHandler;
        _dtdHandler=_dummyHandler;
        _entityResolver=_entityResolver;
        _errorHandler=_errorHandler;
    }

    public void setHandler(DefaultHandler handler) {
        _contentHandler=handler;
        _dtdHandler=handler;
        _entityResolver=handler;
        _errorHandler=handler;
    }

    public void setContentHandler(ContentHandler handler) {
        _contentHandler=handler;
    }

    public void setDtdHandler(DTDHandler handler) {
        _dtdHandler=handler;
    }

    public void setEntityResolver(EntityResolver resolver) {
        _entityResolver=resolver;
    }

    public void setErrorHandler(ErrorHandler handler) {
        _errorHandler=handler;
    }

    // --- content handler implementation ---
    public void characters(char[] ch, int start, int length) throws SAXException {
        _contentHandler.characters(ch,start,length);
    }
    public void endDocument() throws SAXException {
        _contentHandler.endDocument();
    }
    public void endElement(String uri,String localName,String qName) throws SAXException {
        _contentHandler.endElement(uri,localName,qName);
    }
    public void endPrefixMapping(String prefix) throws SAXException {
        _contentHandler.endPrefixMapping(prefix);
    }
    public void ignorableWhitespace(char[] ch, int start, int length) throws SAXException {
        _contentHandler.ignorableWhitespace(ch,start,length);
    }
    public void processingInstruction(String target, String data) throws SAXException {
        _contentHandler.processingInstruction(target,data);
    }
    public void setDocumentLocator(Locator locator) {
        _contentHandler.setDocumentLocator(locator);
    }
    public void skippedEntoty(String name) throws SAXException {
        _contentHandler.skippedEntity(name);
    }
    public void startDocument() throws SAXException {
        _contentHandler.startDocument();
    }
    public void startElement(String uri, String localName,
                             String qName, Attributes atts) throws SAXException {
        _contentHandler.startElement(uri,localName,qName,atts);
    }
    public void startPrefixMapping(String prefix, String uri) throws SAXException {
        _contentHandler.startPrefixMapping(prefix,uri);
    }
    // --- DTDHandler implementation ---
    public void notationDecl(String name, String publicId, 
                                        String systemId) throws SAXException {
        _dtdHandler.notationDecl(name,publicId,systemId);
    }
    public void unparsedEntityDecl(String name,String publicId,
                        String systemId, String notationName) throws SAXException {
        _dtdHandler.unparsedEntityDecl(name,publicId,systemId,notationName);
    }
    // --- EntityResolver implementation ---
    public InputSource resolveEntity(String publicId, String systemId) throws SAXException, IOException {
        return _entityResolver.resolveEntity(publicId,systemId);
    }
    // --- ErrorHandler implementation ---
    public void error(SAXParseException exception) throws SAXException {
        _errorHandler.error(exception);
    }
    public void fataError(SAXParseException exception) throws SAXException {
        _errorHandler.fatalError(exception);
    }
    public void warning(SAXParseException exception) throws SAXException {
        _errorHandler.warning(exception);
    }
}
